@@ -81,7 +81,7 @@ void ContactDelegateCompact::paintContact(QPainter * painter, const QStyleOption
         avatar = SmallIcon("im-user", KIconLoader::SizeMedium);
     }
 
-    style->drawItemPixmap(painter, iconRect, Qt::AlignCenter, avatar.scaled(iconRect.size(), Qt::KeepAspectRatio));
+    style->drawItemPixmap(painter, iconRect, Qt::AlignCenter, avatar.scaled(iconRect.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation));
 
     KTp::Presence presence = index.data(AccountsModel::PresenceRole).value<KTp::Presence>();
 
@@ -94,8 +94,7 @@ void ContactDelegateCompact::paintContact(QPainter * painter, const QStyleOption
 
     painter->drawPixmap(statusIconRect, icon);
 
-    QFont nameFont = KGlobalSettings::smallestReadableFont();
-    nameFont.setPointSize(nameFont.pointSize() + 1);
+    QFont nameFont = KGlobalSettings::generalFont();
 
     const QFontMetrics nameFontMetrics(nameFont);
 
@@ -120,7 +119,7 @@ void ContactDelegateCompact::paintContact(QPainter * painter, const QStyleOption
     painter->setPen(presenceMessagePen);
 
     painter->drawText(presenceMessageRect,
-                      nameFontMetrics.elidedText(presence.statusMessage(),
+                      nameFontMetrics.elidedText(presence.statusMessage().simplified(),
                                                  Qt::ElideRight, presenceMessageRect.width()));
 
     painter->restore();
@@ -130,7 +129,7 @@ QSize ContactDelegateCompact::sizeHintContact(const QStyleOptionViewItem &option
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
-    return QSize(0, 28);
+    return QSize(0, AVATAR_SIZE + 2 * SPACING);
 }
 
 #include "contact-delegate-compact.moc"
